AnimationsBottomSheet extension

on

Methods

animateModalPop({int delayMs = 150}) Widget

Available on Widget, provided by the AnimationsBottomSheet extension

  • Modal Scale-In: Bottom sheet ke items ke liye pop-in effect.
  • animateSheetAction({int delayMs = 300}) Widget

    Available on Widget, provided by the AnimationsBottomSheet extension

  • Action Button Elastic: Confirm/Pay buttons ke liye organic entrance.
  • animateSheetHandle() Widget

    Available on Widget, provided by the AnimationsBottomSheet extension

  • Bottom Sheet Header Pulse: Header bar ya handle ko dhire se highlight karna.
  • animateSheetReveal({int delayMs = 100}) Widget

    Available on Widget, provided by the AnimationsBottomSheet extension

  • Sheet Content Slide: Bottom sheet khulne par content niche se upar aayega. Isme 'Curve.easeOutBack' use kiya hai jo ek halka sa bounce deta hai.