GlobalWidgetListAnimations extension
Methods
-
animateMorphIn(
{int intervalMs = 100, bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- Morph Entrance (Staggered for List)
-
animateStaggered3D(
{int intervalMs = 150, Duration duration = const Duration(milliseconds: 800), bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- PERSPECTIVE 3D (Premium Card Entry)
-
animateStaggered3DFlip(
{int intervalMs = 120, Duration duration = const Duration(milliseconds: 600), bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- PERSPECTIVE FLIP IN
-
animateStaggeredBlur(
{double beginBlur = 10.0, int intervalMs = 120, Duration duration = const Duration(milliseconds: 500), bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- Items reveal with a blur-to-clear effect
-
animateStaggeredBounce(
{int intervalMs = 100, Duration duration = const Duration(milliseconds: 600), bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- STAGGERED BOUNCE (Very Organic feel)
-
animateStaggeredElastic(
{double begin = 0.5, int intervalMs = 80, Duration duration = const Duration(milliseconds: 800), bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- STAGGERED ELASTIC SLIDE
-
animateStaggeredFlip(
{int intervalMs = 150, Duration duration = const Duration(milliseconds: 600), bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- Items flip into view (X-axis rotation)
-
animateStaggeredGlass(
{double beginBlur = 15.0, int intervalMs = 120, Duration duration = const Duration(milliseconds: 500), bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- STAGGERED GLASS (Blur & Zoom)
-
animateStaggeredGlow(
{Color shimmerColor = Colors.white24, int intervalMs = 150, bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- SHIMMER GLOW
-
animateStaggeredList(
{int intervalMs = 80, int durationMs = 300, double beginY = 0.1, bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- Staggered Vertical Slide (Up/Down)
-
animateStaggeredListLeft(
{int intervalMs = 100, double begin = -0.2, int durationMs = 300, bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- Staggered Slide from Left
-
animateStaggeredListRight(
{int intervalMs = 100, double begin = 0.2, int durationMs = 300, bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- Staggered Slide from Right
-
animateStaggeredScale(
{double beginScale = 0.5, int intervalMs = 100, Duration duration = const Duration(milliseconds: 400), Curve curve = Curves.easeOutBack, bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- Items scale up from small to full size one by one
-
animateStaggeredShake(
{int intervalMs = 100, bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- STAGGERED SHAKE ENTRY
-
animateStaggeredShimmer(
{Color? color, int intervalMs = 200, bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- Adds a moving shimmer light effect to each item
-
animateStaggeredSlideFadeX(
{double offsetX = -0.3, int intervalMs = 80, Duration duration = const Duration(milliseconds: 400), Curve curve = Curves.easeOut, bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- Apply staggered slide + fade animation from left
-
animateStaggeredSlideFadeY(
{double offsetY = 0.2, int intervalMs = 80, Duration duration = const Duration(milliseconds: 400), Curve curve = Curves.easeOut, bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- Apply staggered slide + fade animation from bottom
-
animateStaggeredSpiral(
{int intervalMs = 100, Duration duration = const Duration(milliseconds: 500), bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- SPIRAL ENTRANCE
-
animateStaggeredZoomFocus(
{int intervalMs = 120, Duration duration = const Duration(milliseconds: 500), bool animate = true}) → List< Widget> -
Available on List<
Widget> , provided by the GlobalWidgetListAnimations extension- ZOOM OUT ENTRANCE (Focus effect)