TapEffect enum

Inheritance
Available extensions

Values

scale → const TapEffect
fade → const TapEffect
scaleFade → const TapEffect
bounce → const TapEffect
elastic → const TapEffect
pushDown → const TapEffect
tilt → const TapEffect
shake → const TapEffect
flip → const TapEffect
pulse → const TapEffect
zoomOut → const TapEffect
swing → const TapEffect
jelly → const TapEffect
hoverLift → const TapEffect
pop → const TapEffect
wiggle → const TapEffect
blur → const TapEffect
glow → const TapEffect
swirl → const TapEffect
rubberBand → const TapEffect
dropBounce → const TapEffect
wobble → const TapEffect
breathe → const TapEffect
flipX → const TapEffect
flipY → const TapEffect
rotateIn → const TapEffect
shakeY → const TapEffect
none → const TapEffect

Properties

effects List<Effect>

Available on TapEffect, provided by the TapEffectExt extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TapEffect>
A constant List of the values in this enum, in order of their declaration.