FontSizeResolvers class abstract

Constructors

FontSizeResolvers()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

diagonal(num fontSize) double
diameter(num fontSize) double
height(num fontSize) double
radius(num fontSize) double
width(num fontSize) double