Animate class
The Flutter Animate library makes adding beautiful animated effects to your widgets
simple. It supports both a declarative and chained API. The latter is exposed
via the Widget.animate extension, which simply wraps the widget in Animate.
// declarative:
Animate(child: foo, effects: [FadeEffect(), ScaleEffect()])
// chained API:
foo.animate().fade().scale() // equivalent to above
Effects are always run in parallel (ie. the fade and scale effects in the example above would be run simultaneously), but you can apply delays to offset them or run them in sequence.
All effects classes are immutable, and can be shared between Animate
instances, which lets you create libraries of effects to reuse throughout
your app.
List<Effect> transitionIn = [
FadeEffect(duration: 100.ms, curve: Curves.easeOut),
ScaleEffect(begin: 0.8, curve: Curves.easeIn)
];
// then:
Animate(child: foo, effects: transitionIn)
// or:
foo.animate(effects: transitionIn)
Effects inherit some of their properties (delay, duration, curve) from the
previous effect if unspecified. So in the examples above, the scale will use
the same duration as the fade that precedes it. All effects have
reasonable defaults, so they can be used simply: foo.animate().fade()
Note that all effects are composed together, not run sequentially. For example, the following would not fade in myWidget, because the fadeOut effect would still be applying an opacity of 0:
myWidget.animate().fadeOut(duration: 200.ms).fadeIn(delay: 200.ms)
See SwapEffect for one approach to work around this.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- Animate
- Mixed-in types
- Available extensions
Constructors
-
Animate({Key? key, Widget child = const SizedBox.shrink(), List<
Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? value, double? target}) - Creates an Animate instance that will manage a list of effects and apply them to the specified child.
Properties
- adapter → Adapter?
-
An Adapter can drive the animation from an external source (ex. a ScrollController,
ValueNotifier, or arbitrary
0-1value). For more information see Adapter or an adapter class (ChangeNotifierAdapter, ScrollAdapter, ValueAdapter, ValueNotifierAdapter).final - autoPlay → bool
-
Setting autoPlay to
falseprevents the animation from automatically starting its controller (ie. calling AnimationController.forward).final - child → Widget
-
The widget to apply animated effects to.
final
- controller → AnimationController?
-
An external AnimationController can optionally be specified. By default
Animate creates its own controller internally, which can be accessed via
onInit or onPlay.
final
- delay → Duration
-
Defines a delay before the animation is started. Unlike Effect.delay,
this is not a part of the overall animation, and only runs once if the
animation is looped. onPlay is called after this delay.
final
- duration → Duration
-
The total duration for all effects.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onComplete → AnimateCallback?
-
Called when all effects complete. Provides an opportunity to
manipulate the AnimationController (ex. to loop, reverse, etc).
final
- onInit → AnimateCallback?
-
Called immediately after the controller is fully initialized, before
the Animate.delay or the animation starts playing (see: onPlay).
This is not called if an external controller is provided.
final
- onPlay → AnimateCallback?
-
Called when the animation begins playing (ie. after Animate.delay,
immediately after AnimationController.forward is called).
Provides an opportunity to manipulate the AnimationController
(ex. to loop, reverse, stop, etc). This is never called if autoPlay
is
false. See also: onInit.final - rPaddingZero → Widget
-
Available on Widget, provided by the WidgetPaddingX extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → double?
-
Sets a target position for the animation between 0 (start) and 1 (end).
When target is changed, it will animate to the new position.
final
- value → double?
-
Sets an initial position for the animation between 0 (start) and 1 (end).
This corresponds to the
valueof the animation's controller. When value is changed, it will jump to the new position.final
Methods
-
addEffect(
Effect effect) → Animate -
Adds an effect. This is mostly used by Effect extension methods to append effects
to an Animate instance.
override
-
addEffects(
List< Effect> effects) → Animate -
inherited
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
animateAurora(
{bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Multi-Color Aurora
-
animateExposureBlink(
{bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Exposure Blink
-
animateGhostGlow(
{Color color = Colors.redAccent, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Ghost Pulse Glow
-
animateGoldSweep(
{bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Golden Metallic Sweep
-
animateInsetPulse(
{bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Inner Shadow Pulse
-
animateLaserSweep(
{bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Glass Shine (Fast)
-
animateLiquidFill(
{Color color = Colors.greenAccent, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Liquid Fill Shimmer
-
animateList3DDoor(
{required int index, int intervalMs = 80, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Door Opening 3D
-
animateList3DSkew(
{required int index, int intervalMs = 50, int durationMs = 700, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Perspective Skew Slide
-
animateList3DSwing(
{required int index, int intervalMs = 80, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- 3D Swing
-
animateListArcEntry(
{required int index, int intervalMs = 50, int durationMs = 700, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Arc Path Entry
-
animateListBlurFlare(
{required int index, int intervalMs = 70, int durationMs = 900, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Soft Blur Flare
-
animateListBlurSlide(
{required int index, int intervalMs = 60, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Staggered Blur & Slide
-
animateListBorderGlow(
{required int index, int intervalMs = 90, int durationMs = 1000, Color? color, double borderRadius = 12.0, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Border Glow (Rounded)
-
animateListBounce(
{required int index, int intervalMs = 50, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Bounce Up
-
animateListCardDeal(
{required int index, int intervalMs = 100, int durationMs = 700, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Card Stack Reveal
-
animateListColorWave(
{required int index, int intervalMs = 80, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Color Wave
-
animateListColorWaveReverse(
{required int index, int intervalMs = 80, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Reverse Color Wave
-
animateListCyberBlur(
{required int index, int intervalMs = 80, int durationMs = 500, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Cyber Glitch Blur
-
animateListCyberJitter(
{required int index, int intervalMs = 40, int durationMs = 500, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Glitch Jitter
-
animateListDiagonalSlice(
{required int index, int intervalMs = 50, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Diagonal Slice
-
animateListDissolve(
{required int index, int intervalMs = 90, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Particle Dissolve (Reverse)
-
animateListEntry(
{required int index, int intervalMs = 50, int durationMs = 400, double begin = 0.2, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Staggered Slide & Fade
-
animateListExplosion(
{required int index, int intervalMs = 80, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Zoom-In Blur (Explosion)
-
animateListExposurePop(
{required int index, int intervalMs = 60, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Exposure Pop
-
animateListFloatingBubble(
{required int index, int intervalMs = 70, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Floating Bubble
-
animateListFocusDepth(
{required int index, int intervalMs = 100, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Focus In (Depth)
-
animateListFoldFloat(
{required int index, int intervalMs = 120, int durationMs = 1000, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Fold & Float
-
animateListGhostBloom(
{required int index, int intervalMs = 100, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Ghost Bloom
-
animateListGhostSweep(
{required int index, int intervalMs = 40, int durationMs = 400, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Ghost Sweep
-
animateListGlassShine(
{required int index, int intervalMs = 150, int durationMs = 1200, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Glass Morph Shine
-
animateListGlitch(
{required int index, int intervalMs = 50, int durationMs = 400, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Glitch & Slide
-
animateListGridPop(
{required int index, int intervalMs = 40, int durationMs = 400, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Staggered Scale (Pop-in)
-
animateListHelix(
{required int index, int intervalMs = 60, int durationMs = 700, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Perspective Helix
-
animateListHorizon(
{required int index, int intervalMs = 20, int durationMs = 300, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Horizon Tilt
-
animateListInvertReveal(
{required int index, int intervalMs = 50, int durationMs = 500, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Ghost Invert
-
animateListJelly(
{required int index, int intervalMs = 60, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Jelly Wave
-
animateListJellyBounce(
{required int index, int intervalMs = 60, int durationMs = 1000, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Jelly Bounce
-
animateListLiquidSwipe(
{required int index, int intervalMs = 50, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Liquid Swipe
-
animateListMagnetic(
{required int index, int intervalMs = 60, int durationMs = 1200, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Elastic Slide (Magnetic)
-
animateListMagnify(
{required int index, int intervalMs = 50, int durationMs = 700, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Magnifying Glass
-
animateListMorphIn(
{required int index, int intervalMs = 80, int durationMs = 1000, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Morph Entrance
-
animateListNeonFlash(
{required int index, int intervalMs = 120, int durationMs = 500, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Neon Flash
-
animateListNewsSpin(
{required int index, int intervalMs = 100, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Newspaper Spin
-
animateListOrigami(
{required int index, int intervalMs = 80, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Origami Fold
-
animateListPaperLift(
{required int index, int intervalMs = 100, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Paper Slide & Lift
-
animateListPullBack(
{required int index, int intervalMs = 60, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Elastic Pull-Back
-
animateListRevealScale(
{required int index, int intervalMs = 60, int durationMs = 700, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Reveal Clip (Vertical)
-
animateListSepiaTone(
{required int index, int intervalMs = 70, int durationMs = 700, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Sepia Nostalgia
-
animateListShimmerReveal(
{required int index, int intervalMs = 100, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Shimmer Reveal
-
animateListSkewReveal(
{required int index, int intervalMs = 50, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Slide Skew Reveal
-
animateListSkewSlide(
{required int index, int intervalMs = 50, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Skew Entry
-
animateListSlotMachine(
{required int index, int intervalMs = 60, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Slot Machine Reveal
-
animateListSpiral(
{required int index, int intervalMs = 70, int durationMs = 700, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Spiral Rotate
-
animateListSplitReveal(
{required int index, int intervalMs = 70, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Split Reveal (Horizontal)
-
animateListSpotlight(
{required int index, int intervalMs = 120, int durationMs = 800, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Spotlight Focus
-
animateListSpotlightReveal(
{required int index, int intervalMs = 120, int durationMs = 1000, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Final Spotlight Reveal
-
animateListSqueeze(
{required int index, int intervalMs = 50, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Horizontal Squeeze
-
animateListStaggeredFlip(
{required int index, int intervalMs = 60, int durationMs = 500, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Staggered Flip
-
animateListStaggeredPerspective(
{required int index, int intervalMs = 70, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Staggered 3D Perspective
-
animateListStamp(
{required int index, int intervalMs = 80, int durationMs = 500, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Stamp Press
-
animateListSwingDrop(
{required int index, int intervalMs = 90, int durationMs = 1200, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Swing Drop
-
animateListSwingHook(
{required int index, int intervalMs = 70, int durationMs = 1200, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Slide & Swing
-
animateListTiltShift(
{required int index, int intervalMs = 50, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Tilt & Shift
-
animateListTunnel(
{required int index, int intervalMs = 90, int durationMs = 600, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Depth Zoom (Tunnel)
-
animateListVenetian(
{required int index, int intervalMs = 60, int durationMs = 700, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Vertical Venetian
-
animateListVortex(
{required int index, int intervalMs = 100, int durationMs = 700, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Vortex Spin
-
animateModalPop(
{int delayMs = 150}) → Widget -
Available on Widget, provided by the AnimationsBottomSheet extension
- Modal Scale-In: Bottom sheet ke items ke liye pop-in effect.
-
animateNeonFlow(
{Color color = Colors.cyanAccent, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Neon Flow
-
animateRadarScan(
{Color color = Colors.blueAccent, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Radar Scan
-
animateSheetAction(
{int delayMs = 300}) → Widget -
Available on Widget, provided by the AnimationsBottomSheet extension
- Action Button Elastic: Confirm/Pay buttons ke liye organic entrance.
-
animateSheetHandle(
) → Widget -
Available on Widget, provided by the AnimationsBottomSheet extension
- Bottom Sheet Header Pulse: Header bar ya handle ko dhire se highlight karna.
-
animateSheetReveal(
{int delayMs = 100}) → Widget -
Available on Widget, provided by the AnimationsBottomSheet extension
- Sheet Content Slide: Bottom sheet khulne par content niche se upar aayega. Isme 'Curve.easeOutBack' use kiya hai jo ek halka sa bounce deta hai.
-
animateSmoothGlow(
{Color color = Colors.blueAccent, bool animate = true}) → Widget -
Available on Widget, provided by the AnimationListViewItemWidget extension
- Smooth Glow
-
animateWidget3DSkew(
{int delayMs = 0, int durationMs = 700, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- 3D Skew Slide
-
animateWidget3DTilt(
{int delayMs = 0, int durationMs = 600, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- 3D Tilt Entrance
-
animateWidgetAttention(
{int durationMs = 1000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Attention Magnet
-
animateWidgetAurora(
{int durationMs = 4000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Aurora Sweep (Loop)
-
animateWidgetBarGrow(
{int delayMs = 0, int durationMs = 800, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Bar Grow
-
animateWidgetBorderGlow(
{Color color = Colors.greenAccent, int durationMs = 2000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Border Glow Breathe
-
animateWidgetBreathe(
{int durationMs = 1500, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Breathe (Scale Cycle)
-
animateWidgetCardDeal(
{int index = 0, int durationMs = 600, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Credit Card Deal (Staggered)
-
animateWidgetChartLabel(
{int delayMs = 0, int durationMs = 400, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Chart Label Overlay
-
animateWidgetCircleShimmer(
{Alignment alignment = Alignment.center, Color color = Colors.white, int durationMs = 1500, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Circle Radial Shimmer (Loop)
-
animateWidgetCoinJump(
{int delayMs = 0, int durationMs = 800, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Coin Jump & Spin
-
animateWidgetCoinSpin(
{int delayMs = 0, int durationMs = 1000, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Coin Spin (Y-Axis)
-
animateWidgetColorReveal(
{int durationMs = 800, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Color Reveal (B&W to Color)
-
animateWidgetCounterFlip(
{int delayMs = 0, int durationMs = 600, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Counter Flip
-
animateWidgetCyberJitter(
{int delayMs = 0, int durationMs = 500, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Cyber Jitter Reveal
-
animateWidgetCyberScanner(
{Color color = Colors.cyanAccent, int durationMs = 1500, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Cyber Scanner Sweep
-
animateWidgetDigitalGlitch(
{int durationMs = 200, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Digital Glitch Flicker
-
animateWidgetDropBounce(
{int delayMs = 0, int durationMs = 600, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Drop Bounce
-
animateWidgetElasticEntry(
{int delayMs = 0, int durationMs = 800, double begin = 0.5, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Elastic Entrance
-
animateWidgetErrorShake(
{required bool trigger, Color color = Colors.red, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Error Shake
-
animateWidgetFloatUp(
{int delayMs = 0, int durationMs = 2000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Float Up/Down
-
animateWidgetFloatWithShadow(
{int durationMs = 1500, Color shadowColor = Colors.black, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Float with Shadow
-
animateWidgetGhostBloom(
{int delayMs = 0, int durationMs = 800, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Ghost Bloom
-
animateWidgetGhostFloat(
{int durationMs = 3000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Ghost Float (Slow)
-
animateWidgetGlassGlow(
{Color glowColor = Colors.amberAccent, int durationMs = 3000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Glass Morph Glow
-
animateWidgetGlassReveal(
{int delayMs = 0, int durationMs = 500, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Glass Reveal (Blur & Scale)
-
animateWidgetGlassShine(
{int delayMs = 0, int durationMs = 1200, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Glass Shine Sweep
-
animateWidgetGoldShimmer(
{Color color = const Color(0xFFFFD700), int durationMs = 2000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Gold Shimmer
-
animateWidgetGoldSweep(
{int durationMs = 2500, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Gold Metallic Sweep (Loop)
-
animateWidgetHelixEntry(
{int delayMs = 0, int durationMs = 700, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Helix Spin Entrance
-
animateWidgetHoverScale(
{int durationMs = 300, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Hover Scale
-
animateWidgetInsetPulse(
{int durationMs = 1200, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Inset Shadow Pulse (Loop)
-
animateWidgetInsightReveal(
{int delayMs = 0, int durationMs = 500, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Insight Reveal
-
animateWidgetJelly(
{int durationMs = 300, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Jelly Effect
-
animateWidgetLineTrace(
{int delayMs = 0, int durationMs = 1500, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Line Trace
-
animateWidgetLiquidFill(
{Color color = Colors.greenAccent, int durationMs = 3000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Liquid Fill Breathe (Loop)
-
animateWidgetLiquidSlide(
{int delayMs = 0, int durationMs = 600, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Liquid Slide (Modern Perspective)
-
animateWidgetLiquidWave(
{int delayMs = 0, int durationMs = 1000, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Liquid Wave Reveal
-
animateWidgetMagazineSlide(
{int delayMs = 0, int durationMs = 700, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Magazine Slide
-
animateWidgetMagnetic(
{int durationMs = 550, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Magnetic Pull
-
animateWidgetMorphIn(
{int delayMs = 0, int durationMs = 1000, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Morph Entrance
-
animateWidgetNeonFlow(
{Color color = Colors.cyanAccent, int durationMs = 1500, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Neon Flow Sweep (Loop)
-
animateWidgetNeonPulse(
{Color color = Colors.blue, int durationMs = 1500, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Neon Pulse (Breathe)
-
animateWidgetNotifyRipple(
{Color color = Colors.redAccent, int durationMs = 1500, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Notification Ripple
-
animateWidgetOrigamiFold(
{int delayMs = 0, int durationMs = 800, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Origami Vertical Fold
-
animateWidgetPageFlip(
{int delayMs = 0, int durationMs = 800, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Page Flip (3D)
-
animateWidgetPerspectiveFlip(
{int delayMs = 0, int durationMs = 600, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- 3D Perspective Flip (Horizontal)
-
animateWidgetPieSlice(
{int delayMs = 0, int durationMs = 1000, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Pie Slice Rotate
-
animateWidgetPointPop(
{int delayMs = 0, int durationMs = 500, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Data Point Pop
-
animateWidgetProgressFill(
{int delayMs = 0, int durationMs = 1000, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Progress Infill
-
animateWidgetPulse(
{int delayMs = 0, int durationMs = 600, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Pulse (Heartbeat)
-
animateWidgetRadarScan(
{Color color = Colors.blueAccent, int durationMs = 2000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Radar Scan (Radar Loop)
-
animateWidgetRevealDoor(
{int delayMs = 0, int durationMs = 600, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Reveal Door (Vertical)
-
animateWidgetRewardBloom(
{int delayMs = 0, int durationMs = 600, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Reward Bloom
-
animateWidgetScannerBeam(
{Color beamColor = Colors.blueAccent, int durationMs = 2000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Scanner Beam (QR Style)
-
animateWidgetSepia(
{int delayMs = 0, int durationMs = 700, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Sepia Nostalgia
-
animateWidgetShakeX(
{int delayMs = 0, int durationMs = 500, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Shake X
-
animateWidgetShimmerGlow(
{Color color = Colors.white24, int durationMs = 1800, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Shimmer Glow
-
animateWidgetSkewIn(
{int delayMs = 0, double beginSkew = 0.2, int durationMs = 500, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Skew Entry
-
animateWidgetSlideFade(
{int delayMs = 0, int durationMs = 400, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Slide Fade Entrance
-
animateWidgetSlideUpFade(
{int delayMs = 0, int durationMs = 500, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Slide Up Fade
-
animateWidgetSpiralIn(
{int delayMs = 0, int durationMs = 600, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Spiral Entry
-
animateWidgetSpotlightReveal(
{int delayMs = 0, int durationMs = 1000, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Final Luxury Spotlight
-
animateWidgetStamp(
{int delayMs = 0, int durationMs = 500, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Stamp Impact
-
animateWidgetStarShine(
{int durationMs = 2000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Star Particle Shine (Loop)
-
animateWidgetSuccessPop(
{int delayMs = 0, int durationMs = 400, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Success Pop
-
animateWidgetSwingHook(
{int delayMs = 0, int durationMs = 1200, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- 3D Swing Hook
-
animateWidgetTapFeedback(
{required VoidCallback? onTap, TapEffect? effects, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Tap Feedback Detector
-
animateWidgetToastEntry(
{int delayMs = 0, int durationMs = 400, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Toast Entry
-
animateWidgetTunnelIn(
{int delayMs = 0, int durationMs = 800, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Depth Zoom Tunnel
-
animateWidgetTypingDots(
{int delayMs = 0, int durationMs = 300, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Typing Dots Animation
-
animateWidgetWaveFlow(
{int durationMs = 2000, bool repeat = true, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Wave Flow (Loop)
-
animateWidgetWiggle(
{int delayMs = 0, int durationMs = 200, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Wiggle
-
animateWidgetWingEntry(
{int delayMs = 0, int durationMs = 600, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Wing Entry
-
animateWidgetZoomFocus(
{int delayMs = 0, int durationMs = 500, bool repeat = false, bool animate = true}) → Widget -
Available on Widget, provided by the AnimateOnWidget extension
- Focus Zoom
-
center(
{double? heightFactor, double? widthFactor}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Centers the widget within aCenterwidget. -
cornerRadiusWithClipRRect(
double radius) → ClipRRect -
Available on Widget?, provided by the WidgetExtension extension
Adds a uniform corner radius to the widget usingClipRRect. -
cornerRadiusWithClipRRectOnly(
{int bottomLeft = 0, int bottomRight = 0, int topLeft = 0, int topRight = 0}) → ClipRRect -
Available on Widget?, provided by the WidgetExtension extension
Adds rounded corners to the widget usingClipRRectwith custom radii. -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< Animate> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expand(
{int flex = 1}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget withExpanded. -
fit(
{BoxFit? fit, AlignmentGeometry? alignment}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget withFittedBox. -
flexible(
{int flex = 1, FlexFit? fit}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget withFlexible. -
makeRefreshable(
) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget with aRefreshIndicatorto make it refreshable. This assumes that the widget is inside aStackwith aListView. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onTap(
Function? function, {BorderRadius? borderRadius, Color? splashColor, Color? hoverColor, Color? highlightColor}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget with anInkWellfor tap functionality. -
opacity(
{required double opacity, int durationInSecond = 1, Duration? duration}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Adds animated opacity to the widget. -
paddingAll(
double padding) → Padding -
Available on Widget, provided by the PaddingWidgetExtension extension
return padding all -
paddingBottom(
double bottom) → Padding -
Available on Widget, provided by the PaddingWidgetExtension extension
return padding bottom -
paddingLeft(
double left) → Padding -
Available on Widget, provided by the PaddingWidgetExtension extension
return padding left -
paddingOnly(
{double top = 0.0, double left = 0.0, double bottom = 0.0, double right = 0.0}) → Padding -
Available on Widget, provided by the PaddingWidgetExtension extension
return custom padding from each side -
paddingRight(
double right) → Padding -
Available on Widget, provided by the PaddingWidgetExtension extension
return padding right -
paddingSymmetric(
{double vertical = 0.0, double horizontal = 0.0}) → Padding -
Available on Widget, provided by the PaddingWidgetExtension extension
return padding symmetric -
paddingTop(
double top) → Padding -
Available on Widget, provided by the PaddingWidgetExtension extension
return padding top -
rotate(
{required double angle, bool transformHitTests = true, Offset? origin}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Rotates the widget usingTransform.rotate. -
rPaddingAll(
double padding) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
rPaddingOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
rPaddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
scale(
{required double scale, Offset? origin, AlignmentGeometry? alignment, bool transformHitTests = true}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Scales the widget usingTransform.scale. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
translate(
{required Offset offset, bool transformHitTests = true, Key? key}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Translates (moves) the widget usingTransform.translate. -
validate(
{Widget value = const SizedBox()}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Returns the widget if it is not null, otherwise returns a default value. -
visible(
bool visible, {Widget? defaultWidget}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Controls the visibility of the widget. -
withHeight(
double height) → SizedBox -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget inside aSizedBoxwith a custom height. -
withShaderMask(
List< Color> colors, {BlendMode blendMode = BlendMode.srcATop}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget with aShaderMaskusing a list of colors. -
withShaderMaskGradient(
Gradient gradient, {BlendMode blendMode = BlendMode.srcATop}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget with aShaderMaskusing a customGradient. -
withSize(
{double width = 0.0, double height = 0.0}) → SizedBox -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget inside aSizedBoxwith a custom height and width. -
withTooltip(
{required String msg}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget with aTooltip. -
withWidth(
double width) → SizedBox -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget inside aSizedBoxwith a custom width.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaultCurve ↔ Curve
-
Default curve for effects.
getter/setter pair
- defaultDuration ↔ Duration
-
Default duration for effects.
getter/setter pair
- reparentTypes ↔ Map
-
Widget types to reparent, mapped to a method that handles that type. This is used
to make it easy to work with widgets that require specific parents. For example,
the Positioned widget, which needs its immediate parent to be a Stack.
getter/setter pair
- restartOnHotReload ↔ bool
-
If true, then animations will automatically restart whenever a hot reload
occurs. This is useful for testing animations quickly during development.
getter/setter pair