ShimmerWidget class

Lightweight shimmer effect without external packages.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromColors({required Widget child, required Color baseColor, required Color highlightColor, Duration period = const Duration(milliseconds: 1500)}) Widget