isBottom property
bool
get
isBottom
Returns true if the alignment is vertically aligned toward the bottom.
Implementation
bool get isBottom => verticalAxis == AlignmentVertical.bottom;
Returns true if the alignment is vertically aligned toward the bottom.
bool get isBottom => verticalAxis == AlignmentVertical.bottom;