isEnd property
bool
get
isEnd
Returns true when start points toward the layout end edge.
Implementation
bool get isEnd => horizontalAxisDirectional == AlignmentHorizontal.right;
Returns true when start points toward the layout end edge.
bool get isEnd => horizontalAxisDirectional == AlignmentHorizontal.right;