isStart property
bool
get
isStart
Returns true when start points toward the layout start edge.
Implementation
bool get isStart => horizontalAxisDirectional == AlignmentHorizontal.left;
Returns true when start points toward the layout start edge.
bool get isStart => horizontalAxisDirectional == AlignmentHorizontal.left;