isLeft property
bool
get
isLeft
Returns true if the alignment is horizontally aligned toward the left.
Implementation
bool get isLeft => horizontalAxis == AlignmentHorizontal.left;
Returns true if the alignment is horizontally aligned toward the left.
bool get isLeft => horizontalAxis == AlignmentHorizontal.left;