isRight property
bool
get
isRight
Returns true if the alignment is horizontally aligned toward the right.
Implementation
bool get isRight => horizontalAxis == AlignmentHorizontal.right;
Returns true if the alignment is horizontally aligned toward the right.
bool get isRight => horizontalAxis == AlignmentHorizontal.right;