isTop property
bool
get
isTop
Returns true if the alignment is vertically aligned toward the top.
Implementation
bool get isTop => verticalAxis == AlignmentVertical.top;
Returns true if the alignment is vertically aligned toward the top.
bool get isTop => verticalAxis == AlignmentVertical.top;