isBottomResolved method
Returns true when the resolved alignment is toward the bottom.
Implementation
bool isBottomResolved(TextDirection textDirection) =>
resolveAlignment(textDirection).isBottom;
Returns true when the resolved alignment is toward the bottom.
bool isBottomResolved(TextDirection textDirection) =>
resolveAlignment(textDirection).isBottom;