getArguments property
dynamic
get
getArguments
Gets the arguments passed to the current named route.
This property retrieves any arguments that were passed when
navigating to the current route using Navigator.pushNamed.
Implementation
dynamic get getArguments => ModalRoute.of(this)?.settings.arguments;