textTheme property
TextTheme
get
textTheme
Returns the textTheme of the current theme.
This property provides access to the text styles defined in the current theme's textTheme.
It can be used to retrieve predefined text styles like headline1, bodyText1, etc.
Implementation
TextTheme get textTheme => theme.textTheme;