isNotNull property
bool
get
isNotNull
Returns true if the given date is not null.
Implementation
bool get isNotNull => !isNull;
Returns true if the given date is not null.
bool get isNotNull => !isNull;