ListNullExtension<T> extension
- on
-
- List<
T> ?
- List<
Properties
- firstOrNull → T?
-
Available on List<
Returns the first element or null if list is null or emptyT> ?, provided by the ListNullExtension extensionno setter - isNotNullAndNotEmpty → bool
-
Available on List<
Returns true if the list is not null and not emptyT> ?, provided by the ListNullExtension extensionno setter - isNullOrEmpty → bool
-
Available on List<
Returns true if the list is null or emptyT> ?, provided by the ListNullExtension extensionno setter - lastOrNull → T?
-
Available on List<
Returns the last element or null if list is null or emptyT> ?, provided by the ListNullExtension extensionno setter
Methods
-
repeat(
int times) → List< T> -
Available on List<
🚀 Repeats the list itemsT> ?, provided by the ListNullExtension extensiontimesnumber of times If list is null/empty or times <= 0, returns an empty list. -
validate(
) → List< T> -
Available on List<
Returns the list if not null, otherwise returns an empty listT> ?, provided by the ListNullExtension extension