firstOrNull property
T?
get
firstOrNull
Returns the first element or null if list is null or empty
Implementation
T? get firstOrNull => this?.firstOrNull;
Returns the first element or null if list is null or empty
T? get firstOrNull => this?.firstOrNull;