isNotNullAndNotEmpty property
bool
get
isNotNullAndNotEmpty
Returns true if the list is not null and not empty
Implementation
bool get isNotNullAndNotEmpty => this != null && this!.isNotEmpty;
Returns true if the list is not null and not empty
bool get isNotNullAndNotEmpty => this != null && this!.isNotEmpty;