validate method
Returns the list if not null, otherwise returns an empty list
Implementation
List<T> validate() {
return this ?? <T>[];
}
Returns the list if not null, otherwise returns an empty list
List<T> validate() {
return this ?? <T>[];
}