ListnumManipulation extension
Properties
- isNotNullAndEmpty → bool
-
Available on List<
Returnsnum> ?, provided by the ListnumManipulation extensiontrueif the list is notnulland contains at least one element.no setter - isNullAndEmpty → bool
-
Available on List<
Returnsnum> ?, provided by the ListnumManipulation extensiontrueif the list is eithernullor empty.no setter - total → num
-
Available on List<
Returns the sum of all elements in the list. If the list isnum> ?, provided by the ListnumManipulation extensionnullor empty, it returns0.no setter