addKeyValue method
Returns a new map with key added or replaced.
Implementation
Map<K, V> addKeyValue(K key, V value) => {...this, key: value};
Returns a new map with key added or replaced.
Map<K, V> addKeyValue(K key, V value) => {...this, key: value};