spaceMax method

Widget spaceMax()

A widget that takes, at most, an amount of space in a Row, Column,or Flex widget. The spaceMax property converts the integer value to a SpaceMax widget, which is useful for creating flexible layouts where certain elements need to occupy a specific amount of space.

Implementation

Widget spaceMax() => SpaceMax(validate().toDouble());