WidgetExtension extension
- on
Methods
-
center(
{double? heightFactor, double? widthFactor}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Centers the widget within aCenterwidget. -
cornerRadiusWithClipRRect(
double radius) → ClipRRect -
Available on Widget?, provided by the WidgetExtension extension
Adds a uniform corner radius to the widget usingClipRRect. -
cornerRadiusWithClipRRectOnly(
{int bottomLeft = 0, int bottomRight = 0, int topLeft = 0, int topRight = 0}) → ClipRRect -
Available on Widget?, provided by the WidgetExtension extension
Adds rounded corners to the widget usingClipRRectwith custom radii. -
expand(
{dynamic flex = 1}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget withExpanded. -
fit(
{BoxFit? fit, AlignmentGeometry? alignment}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget withFittedBox. -
flexible(
{dynamic flex = 1, FlexFit? fit}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget withFlexible. -
makeRefreshable(
) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget with aRefreshIndicatorto make it refreshable. This assumes that the widget is inside aStackwith aListView. -
onTap(
Function? function, {BorderRadius? borderRadius, Color? splashColor, Color? hoverColor, Color? highlightColor}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget with anInkWellfor tap functionality. -
opacity(
{required double opacity, int durationInSecond = 1, Duration? duration}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Adds animated opacity to the widget. -
rotate(
{required double angle, bool transformHitTests = true, Offset? origin}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Rotates the widget usingTransform.rotate. -
scale(
{required double scale, Offset? origin, AlignmentGeometry? alignment, bool transformHitTests = true}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Scales the widget usingTransform.scale. -
translate(
{required Offset offset, bool transformHitTests = true, Key? key}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Translates (moves) the widget usingTransform.translate. -
validate(
{Widget value = const SizedBox()}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Returns the widget if it is not null, otherwise returns a default value. -
visible(
bool visible, {Widget? defaultWidget}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Controls the visibility of the widget. -
withHeight(
double height) → SizedBox -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget inside aSizedBoxwith a custom height. -
withShaderMask(
List< Color> colors, {BlendMode blendMode = BlendMode.srcATop}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget with aShaderMaskusing a list of colors. -
withShaderMaskGradient(
Gradient gradient, {BlendMode blendMode = BlendMode.srcATop}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget with aShaderMaskusing a customGradient. -
withSize(
{double width = 0.0, double height = 0.0}) → SizedBox -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget inside aSizedBoxwith a custom height and width. -
withTooltip(
{required String msg}) → Widget -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget with aTooltip. -
withWidth(
double width) → SizedBox -
Available on Widget?, provided by the WidgetExtension extension
Wraps the widget inside aSizedBoxwith a custom width.