RxDateTime class

Lightweight reactive wrapper for DateTime without external state libraries.

Inheritance
Available extensions

Constructors

RxDateTime(DateTime value)
RxDateTime.now()
factory

Properties

dateTime DateTime
getter/setter pair
endOfDay DateTime
no setter
endOfMonth DateTime
no setter
endOfWeek DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isToday bool
no setter
isYesterday bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startOfDay DateTime
no setter
startOfMonth DateTime
no setter
startOfWeek DateTime
no setter
value DateTime
The current value stored in this notifier.
getter/setter pairinherited

Methods

addDuration(Duration duration) RxDateTime
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
builder({required TransitionBuilder builder, Widget? child}) Widget

Available on Listenable, provided by the ListenableExtension extension

Provides an AnimatedBuilder widget that listens to the Listenable and rebuilds its widget tree when the animation value changes.
differenceInDays(DateTime other) int
differenceInHours(DateTime other) int
differenceInMinutes(DateTime other) int
dispose() → void
Discards any resources used by the object.
inherited
format([String pattern = 'yyyy-MM-dd HH:mm:ss']) String
isAfter(DateTime other) bool
isAtSameMomentAs(DateTime other) bool
isBefore(DateTime other) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setTime({int hour = 0, int minute = 0, int second = 0, int millisecond = 0}) RxDateTime
subtractDuration(Duration duration) RxDateTime
timeAgo() String
toLocalTime() RxDateTime
toString() String
A string representation of this object.
inherited
toUtcTime() RxDateTime

Operators

operator ==(Object other) bool
The equality operator.
inherited