allowDecimalZero property
When true, a leading 0 is allowed only when it is the start of a
decimal (0. or 0.5). When false, any leading 0 is rejected.
Implementation
final bool allowDecimalZero;
When true, a leading 0 is allowed only when it is the start of a
decimal (0. or 0.5). When false, any leading 0 is rejected.
final bool allowDecimalZero;