PrintfConfig class

Global behaviour for printf helpers.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

enabled bool
Master switch for all printf output.
getter/setter pair
logName String
Name passed to dart:developer developer.log.
getter/setter pair
minLevel PrintfLevel
Minimum level to print. Logs below this are ignored.
getter/setter pair
onlyInDebugMode bool
When true, output is suppressed outside kDebugMode.
getter/setter pair
showCaller bool
Default caller file:// link to the printf call site (IDE-clickable).
getter/setter pair
showTimestamp bool
Default timestamp prefix for every log line.
getter/setter pair
When true, caller links use file:///absolute/path.dart:line:column. When false, uses the raw URI from the stack frame (package: etc.).
getter/setter pair