PrintfLevel enum
Log severity used by printf and shortcuts like printfError.
Values
- debug → const PrintfLevel
-
const PrintfLevel(0, 'DEBUG', PrintfStyle.debug) - info → const PrintfLevel
-
const PrintfLevel(1, 'INFO', PrintfStyle.info) - success → const PrintfLevel
-
const PrintfLevel(2, 'OK', PrintfStyle.success) - warning → const PrintfLevel
-
const PrintfLevel(3, 'WARN', PrintfStyle.warning) - error → const PrintfLevel
-
const PrintfLevel(4, 'ERROR', PrintfStyle.error)
Properties
- defaultStyle → PrintfStyle
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - priority → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PrintfLevel> - A constant List of the values in this enum, in order of their declaration.