MapInfoWindowAdapter class abstract

Adapter for map controllers (e.g. Google Maps) without package dependencies.

Implementers

Constructors

MapInfoWindowAdapter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

devicePixelRatio(BuildContext context) double
getScreenCoordinate(MapLatLng latLng) Future<MapScreenCoordinate>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited