DashDivider constructor
const
DashDivider({})
Creates a DashDivider widget.
The height parameter defines the height of the divider.
The dashWidth parameter defines the width of each dash.
The dashSpace parameter defines the space between each dash.
The color parameter defines the color of the dashes.
Implementation
const DashDivider({
super.key,
this.height = 1,
this.dashWidth = 10,
this.dashSpace = 2,
this.color,
}) : assert(dashWidth >= 1.0 && dashWidth <= 10.0),
assert(dashSpace >= 1.0 && dashSpace <= 10.0);