SeparatedColumn constructor
const
SeparatedColumn({
- Key? key,
- TextBaseline? textBaseline,
- TextDirection? textDirection,
- List<
Widget> children = const <Widget>[], - bool includeFirstSeparator = false,
- bool includeLastSeparator = false,
- MainAxisSize mainAxisSize = MainAxisSize.max,
- VerticalDirection verticalDirection = VerticalDirection.down,
- MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start,
- CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center,
- required IndexedWidgetBuilder separatorBuilder,
Creates a vertical array of children with separators between each item.
If crossAxisAlignment is CrossAxisAlignment.baseline, then
textBaseline must not be null.
The textDirection argument defaults to the ambient Directionality, if
any. If there is no ambient directionality, and a text direction is going
to be necessary to disambiguate start or end values for the
crossAxisAlignment, the textDirection must not be null.
Implementation
const SeparatedColumn({
super.key,
this.textBaseline,
this.textDirection,
this.children = const <Widget>[],
this.includeFirstSeparator = false,
this.includeLastSeparator = false,
this.mainAxisSize = MainAxisSize.max,
this.verticalDirection = VerticalDirection.down,
this.mainAxisAlignment = MainAxisAlignment.start,
this.crossAxisAlignment = CrossAxisAlignment.center,
required this.separatorBuilder,
});