SpaceMax constructor
Creates a widget that takes, at most, the specified mainAxisExtent of
space in a Row, Column, or Flex widget.
The mainAxisExtent must not be null and must be positive.
The crossAxisExtent must be either null or positive.
Implementation
const SpaceMax(
this.mainAxisExtent, {
super.key,
this.crossAxisExtent,
this.color,
}) : assert(mainAxisExtent >= 0 && mainAxisExtent < double.infinity),
assert(crossAxisExtent == null || crossAxisExtent >= 0);