builder property
Function that builds the widget.
context is the current BuildContext.
onTap is the function to pass to your button or InkWell.
Implementation
final Widget Function(BuildContext context, FutureVoidCallback? onTap)
builder;
Function that builds the widget.
context is the current BuildContext.
onTap is the function to pass to your button or InkWell.
final Widget Function(BuildContext context, FutureVoidCallback? onTap)
builder;