PointedEdgeClipper class
PointedEdgeClipper that can be used with ClipPath to clip widget in Pointed Edge shape
- Inheritance
-
- Object
- Listenable
- CustomClipper<
Path> - PointedEdgeClipper
- Available extensions
Constructors
- PointedEdgeClipper({Edge edge = Edge.bottom, int points = 20, double depth = 10})
Properties
- depth → double
-
Depth of pointed edge
final
- edge → Edge
-
Clipper sides: Edge.horizontal, Edge.vertical, Edge.top, Edge.bottom, Edge.left, Edge.right, Edge.all
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- points → int
-
Number of point edges
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to reclip.
inherited
-
builder(
{required TransitionBuilder builder, Widget? child}) → Widget -
Available on Listenable, provided by the ListenableExtension extension
Provides anAnimatedBuilderwidget that listens to theListenableand rebuilds its widget tree when the animation value changes. -
getApproximateClipRect(
Size size) → Rect -
Returns an approximation of the clip returned by getClip, as
an axis-aligned Rect. This is used by the semantics layer to
determine whether widgets should be excluded.
inherited
-
getClip(
Size size) → Path -
Returns a description of the clip given that the render object being
clipped is of the given size.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to reclip.
inherited
-
shouldReclip(
covariant CustomClipper< Path> oldClipper) → bool -
Called whenever a new instance of the custom clipper delegate class is
provided to the clip object, or any time that a new clip object is created
with a new instance of the custom clipper delegate class (which amounts to
the same thing, because the latter is implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited