ShadowRadius class
Constructors
- ShadowRadius({Radius topLeft = Radius.zero, Radius topRight = Radius.zero, Radius bottomLeft = Radius.zero, Radius bottomRight = Radius.zero})
- ShadowRadius.all(Radius radius)
-
Creates a border radius where all radii are
radius. - ShadowRadius.circular(double radius)
- Creates a border radius where all radii are Radius.circular(radius).
- ShadowRadius.horizontal({Radius left = Radius.zero, Radius right = Radius.zero})
- Creates a horizontally symmetrical border radius where the left and right sides of the rectangle have the same radii.
- ShadowRadius.only({Radius topLeft = Radius.zero, Radius topRight = Radius.zero, Radius bottomLeft = Radius.zero, Radius bottomRight = Radius.zero})
-
Creates a border radius with only the given non-zero values. The other corners will be right angles.
const
- ShadowRadius.vertical({Radius top = Radius.zero, Radius bottom = Radius.zero})
- Creates a vertically symmetric border radius where the top and bottom sides of the rectangle have the same radii.
Properties
- bottomLeft → Radius
-
final
- bottomRight → Radius
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topLeft → Radius
-
final
- topRight → Radius
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- zero → ShadowRadius
-
A border radius with all zero radii.
no setter