animateSheetReveal method
- Sheet Content Slide: Bottom sheet khulne par content niche se upar aayega. Isme 'Curve.easeOutBack' use kiya hai jo ek halka sa bounce deta hai.
Implementation
Widget animateSheetReveal({int delayMs = 100}) {
return animate(delay: delayMs.ms)
.fadeIn(duration: 400.ms)
.moveY(begin: 50, end: 0, duration: 500.ms, curve: Curves.easeOutBack);
}