ScreenUtil class

Available extensions

Constructors

ScreenUtil()
factory

Properties

bottomBarHeight double
no setter
calculator ScaleCalculator
no setter
fontSizeResolver FontSizeResolver?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
orientation Orientation
no setter
pixelRatio double?
no setter
portraitHeight double

Available on ScreenUtil, provided by the ScreenUtilPortrait extension

no setter
portraitWidth double

Available on ScreenUtil, provided by the ScreenUtilPortrait extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleHeight double
no setter
scaleWidth double
no setter
screenHeight double
no setter
screenWidth double
no setter
statusBarHeight double
no setter
textScaleFactor TextScaler
no setter

Methods

diagonal(num d) double
diameter(num d) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
portraitSetHeight(num height) double

Available on ScreenUtil, provided by the ScreenUtilPortrait extension

portraitSetWidth(num width) double

Available on ScreenUtil, provided by the ScreenUtilPortrait extension

radius(num r) double
setHeight(num height) double
setWidth(num width) double
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ScreenUtil
no setter
scaleText double
no setter

Static Methods

configure({MediaQueryData? data, Size? designSize, bool? splitScreenMode, double? splitScreenMinHeight, bool? minTextAdapt, FontSizeResolver? fontSizeResolver}) → void
deviceType(BuildContext context) DeviceType
enableScale({bool enableWH()?, bool enableText()?}) → void
ensureScreenSize([FlutterView? window, Duration duration = const Duration(milliseconds: 10)]) Future<void>
ensureScreenSizeAndInit(BuildContext context, {Size designSize = defaultSize, bool splitScreenMode = false, double splitScreenMinHeight = ScreenUtilDefaults.splitScreenMinHeight, bool minTextAdapt = false, FontSizeResolver? fontSizeResolver}) Future<void>
init(BuildContext context, {Size designSize = defaultSize, bool splitScreenMode = false, double splitScreenMinHeight = ScreenUtilDefaults.splitScreenMinHeight, bool minTextAdapt = false, FontSizeResolver? fontSizeResolver}) → void
registerToBuild(BuildContext context, [bool withDescendants = false]) → void
setHorizontalSpacing(num width) SizedBox
setHorizontalSpacingDiagonal(num width) SizedBox
setHorizontalSpacingDiameter(num width) SizedBox
setHorizontalSpacingRadius(num width) SizedBox
setSp(num fontSize) double
setVerticalSpacing(num height) SizedBox
setVerticalSpacingDiagonal(num height) SizedBox
setVerticalSpacingDiameter(num height) SizedBox
setVerticalSpacingFromWidth(num height) SizedBox
setVerticalSpacingRadius(num height) SizedBox

Constants

defaultSize → const Size