AlignmentDirectionalExtensions extension
Direction-aware checks for AlignmentDirectional using the start axis.
Properties
- horizontalAxisDirectional → AlignmentHorizontal
-
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Horizontal bucket based on the directionalstartcoordinate.no setter - isBottom → bool
-
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Returnstrueif the alignment is vertically aligned toward the bottom.no setter - isCenter → bool
-
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Returnstruewhen both axes are centered.no setter - isCenterHorizontal → bool
-
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Returnstruewhenstartis centered horizontally.no setter - isCenterVertical → bool
-
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Returnstrueif the alignment is vertically centered.no setter - isEnd → bool
-
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Returnstruewhenstartpoints toward the layout end edge.no setter - isStart → bool
-
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Returnstruewhenstartpoints toward the layout start edge.no setter - isTop → bool
-
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Returnstrueif the alignment is vertically aligned toward the top.no setter - verticalAxis → AlignmentVertical
-
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Resolved vertical bucket for this alignment.no setter
Methods
-
isLeftResolved(
TextDirection textDirection) → bool -
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Returnstruewhen resolved alignment is toward the physical left. -
isRightResolved(
TextDirection textDirection) → bool -
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Returnstruewhen resolved alignment is toward the physical right. -
resolveAlignment(
TextDirection textDirection) → Alignment -
Available on AlignmentDirectional, provided by the AlignmentDirectionalExtensions extension
Resolves to Alignment fortextDirection.