flutter_helper_kit library
A comprehensive utility kit containing high-performance extensions, production-ready pagination widgets, geometric squircle paths, and advanced formatters.
Modular imports (smaller compile surface):
flutter_helper_kit_extensions.dartflutter_helper_kit_widgets.dartflutter_helper_kit_animation.dartflutter_helper_kit_responsive.dartflutter_helper_kit_utils.dart
Classes
-
ActionSheetItem<
T> - Generic model for action sheet items.
- Adapter
- Adapters provide a mechanism to drive an animation from an arbitrary source. For example, synchronizing an animation with a scroll, controlling an animation with a slider input, or progressing an animation based on the time of day.
- AlignEffect
-
An effect that animates the target between the specified begin and end
alignments (via Align).
Defaults to
begin=Align.topCenter, end=Align.center. - Animate
-
The Flutter Animate library makes adding beautiful animated effects to your widgets
simple. It supports both a declarative and chained API. The latter is exposed
via the
Widget.animateextension, which simply wraps the widget inAnimate. - AnimatedDigitController
- 动画数字控制器
- AnimatedDigitWidget
- 动画数字 Widget
- AnimatedDigitWidgetState
- AnimatedGestureDetector
- AnimatedListWrapper
-
AnimateList<
T extends Widget> -
Applies animated effects to a list of widgets. It does this by wrapping each
widget in Animate, and then proxying calls to all instances. It can
also offset the timing of each widget's animation via
interval. - Annotation
- Defines a customizable pattern within text, such as hashtags, URLs, or mentions.
- AppButton
- Default App Button
- AppButtonState
- AppCupertinoActionSheet
- AppCupertinoDialog
- AvatarGlow
- A widget that adds a glowing effect around its child.
- AvatarGlowMultiColor
- A widget that adds a glowing effect around with multipale colors its child.
- BlurEffect
-
An effect that animates a blur on the target between the
specified begin and end blur radiuses (via ImageFiltered).
Defaults to
begin=0, end=4. - BoxShadowEffect
-
An effect that animates a BoxShadow between begin and end (via DecoratedBox).
A value of
nullfor either will be interpreted as a shadow that matches the other shadow but with a zero offset and blurRadius. You can also specify a borderRadius that defines rounded corners for the shadow. Defaults tobegin=null, end=BoxShadow(color: Color(0x80000000), blurRadius: 8.0, offset: Offset(0.0, 4.0)) - CallbackEffect
- An effect that calls a callback function at a particular point in the animation. It includes a boolean value indicating if the animation is playing in reverse.
- CallbackMapInfoWindowAdapter
- Wires MapCustomInfoWindow to any map SDK via callbacks (no extra dependencies).
- CenterTextDivider
- ChangeNotifierAdapter
-
Drives an Animate animation from a ChangeNotifier. The valueGetter
should provide a value in the range
0-1when a change occurs. - CircleClipper
- CircleContainer
- A circular container with equal width and height from size.
- CircularPercentIndicator
- A circular progress indicator with optional animation, gradients, and arcs.
- ColorEffect
-
An effect that animates a Color between begin and end, composited with
the target using blendMode (via ColorFiltered). A color value of
nullwill be interpreted as a fully transparent version of the other color. Defaults tobegin=null, end=Color(0x800099FF). - CrossfadeEffect
- An effect that crossfades the incoming child (including preceeding effects) with a new widget (via Stack and FadeTransition). It uses a builder so that the effect can be reused, but note that the builder is only called once when the effect initially builds.
- CustomBanner
- CustomEffect
- Provide an easy way to add custom animated effects via a builder method that accepts a BuildContext, target child, and calculated animation value between begin and end.
- CustomIndicator
- DashDivider
- DecimalTextInputFormatter
- An advanced TextInputFormatter for numeric fields.
- DottedBorderWidget
- DottedBorderWidgetState
- DoublePressBackWidget
- A widget that handles double press back navigation.
-
DropdownItem<
T> -
Effect<
T> - An empty effect that all other effects extend. It can be added to Animate, but has no visual effect.
- EffectEntry
-
Because Effect classes are immutable and may be reused between multiple
Animate (or AnimateList) instances, an EffectEntry is created to store
values that may be different between instances. For example, due to an
intervalonAnimateList, or from inheriting timing parameters. - EffectList
- Simple helper class to build a list of effects via the chained api. Example:
- ElevationEffect
-
An effect that animates a Material elevation shadow between begin and end (via PhysicalModel).
You can also specify a shadow color and borderRadius to add rounded corners.
It defaults to
begin=0, end=8. - FadeEffect
-
Animates the opacity of the target between the specified
begin and end values (via FadeTransition).
It defaults to
begin=0, end=1. - FlipEffect
- An effect that animates a 2.5D card flip rotation effect (via Transform). The effect can be horizontal or vertical.
- FlutterDateTime
-
Cross-platform date / time pickers built on top of
flutter_helper_kit. -
FlutterListView<
T> - A widget that displays a list of items with dynamic heights in a scrollable view.
- FlutterTag
- FlutterTagAnimation
- FlutterTagBorderGradient
- A custom BoxBorder that draws a gradient border around a widget.
- FlutterTagGradient
- A utility class for creating gradients of various types used in Flutter badges.
- FlutterTagPosition
- FlutterTagPositioned
-
A widget that positions a child widget within a parent widget using
the provided
FlutterTagPositionBaseparameters. - FlutterTagState
- FlutterTagStyle
- FlutterToast
- the package library class for calling from client end.
- FollowPathEffect
- An effect that moves the target following the specified path (via Transform). The path coordinates are relative to the target's nominal position.
- FontSizeResolvers
-
GenericPickerSheet<
T extends DropdownItem> - Material bottom-sheet picker for single or multi-select dropdown lists.
- GoogleLogoWidget
- A widget that displays the Google logo using CustomPaint.
- GradientText
- HiMessages
- LinearPercentIndicator
- A linear progress indicator with optional animation, gradients, and labels.
- ListenEffect
- An effect that calls a callback function with its current animation value between begin and end.
- ListTileShimmer
- ListTileShimmerState
- ListViewPagination
- LookupMessages
- MapCustomInfoWindow
- MapCustomInfoWindowController
- Controller to add, update and control the custom info window.
- MapInfoWindowAdapter
- Adapter for map controllers (e.g. Google Maps) without package dependencies.
- MapLatLng
- Simple latitude/longitude pair for map overlays.
- MapScreenCoordinate
- Screen coordinate returned by MapInfoWindowAdapter.getScreenCoordinate.
- Marquee
- MoveEffect
-
An effect that moves the target between the specified begin and end
offsets (via Transform.translate).
Defaults to
begin=Offset(0, -16), end=Offset.zero. transformHitTests is simply passed on to Transform.translate. - MultiSegmentLinearIndicator
- A multi-segment linear progress bar.
- MyDropdownItem
- NoLeadingSpaceFormatter
- A text input formatter that prevents users from starting the text with a space.
- NonZeroFormatter
- A lightweight TextInputFormatter that keeps numeric input non-zero.
- NoSpaceFormatter
- user can't use space
- NP
- Numeral
- A utility class for formatting numbers in either Indian or International numeral systems.
- OutlineAvatarGlow
- OutlineAvatarGlowMultiColor
- PasswordStrengthIndicator
- PasswordStrengthIndicatorState
- PlayStoreShimmer
- PlayStoreShimmerState
- PointedEdgeClipper
- PointedEdgeClipper that can be used with ClipPath to clip widget in Pointed Edge shape
- PrintfConfig
- Global behaviour for printf helpers.
- PrintfStyle
- ANSI styling for printf output.
- ProfilePageShimmer
- ProfilePageShimmerState
- ProfileShimmer
- ProfileShimmerState
- RandomImage
- RandomPicsumImage
- RatingBarWidget
- RatingBarWidget
- RatingBarWidgetState
- ReadMoreText
- ReadMoreTextEnhanced
- ReadMoreTextEnhancedState
- ReadMoreTextState
- RebuildFactors
- REdgeInsets
- REdgeInsetsDirectional
- RegExpPatterns
- Predefined Patterns for different validation
- RenderSliverSpace
- ResponsiveScope
- Provides ScaleCalculator to the widget tree without relying on globals.
- RotateEffect
-
Effect that rotates the target between begin and end (via RotationTransition).
Values are specified in "turns" (360° or 2𝝅 radians), so a
begin=0.25, end=2.25would start with the child rotated a quarter turn clockwise (90 degrees), and rotate two full turns (ending at 810 degrees). Defaults tobegin=-1.0, end=0. - RoundedCheckBox
- Widget that draw a beautiful checkbox rounded. Provided with animation if wanted
- RoundedCheckBoxState
- RoundedEdgeClipper
- RoundedEdgeClipper that can be used with ClipPath to clip widget in Rounded Edge shape
- RPadding
- RSizedBox
- RSliverPadding
- RSliverSizedBox
- RxDateTime
- Lightweight reactive wrapper for DateTime without external state libraries.
- RxnDateTime
- Nullable reactive DateTime.
- SaturateEffect
-
An effect that animates the color saturation of the target. The begin and
end values indicate the saturation level, where
0is fully desaturated (ie. grayscale) and1is normal saturation. Values>1will oversaturate. Defaults tobegin=0, end=1. - ScaleCalculator
- Pure scaling math for responsive layouts.
- ScaleEffect
-
An effect that scales the target between the specified begin and end
offset values (via Transform.scale).
Defaults to
begin=Offset(0,0), end=Offset(1,1). - ScreenUtil
- ScreenUtilDefaults
- Shared defaults for responsive scaling.
- ScreenUtilInit
- ScrollAdapter
- Drives an Animate animation from a ScrollController.
- SegmentLinearIndicator
- A colored segment for MultiSegmentLinearIndicator.
- SeparatedColumn
- A widget that arranges its children in a vertical column with separators between them.
- ShaderEffect
- Effect that applies an animated fragment shader to a target. See Writing and using fragment shaders for information on how to include shaders in your app.
- ShaderUpdateDetails
- Passed to the ShaderEffect.update callback. Contains information necessary for updating the shader:
- ShadowRadius
- ShakeEffect
- Effect that shakes the target, using translation, rotation, or both (via Transform).
- SharpBorderRadius
- SharpCircleBorder
- SharpClipCircle
- SharpClipRect
- SharpProcessedRadius
- SharpRadius
- SharpRectangleBorder
- ShimmerEffect
- An effect that animates gradient overlay effects (via ShaderMask), such as the shimmer loading effect popularized by facebook.
- SingleDigitData
- 单个包装的字符/数字依赖配置数据源
- SingleDigitProvider
-
The SingleDigitData
DIprovider widget - SlideEffect
-
An effect that moves the target based on a fraction of its size
per the specified begin and end offsets (via SlideTransition).
Defaults to
begin=Offset(0, -0.5), end=Offset.zero(slide down from half its height). - SliderButton
- SlideTween
- SliverSpace
- A sliver that takes a fixed amount of space.
- Space
- A widget that takes a fixed amount of space in the direction of its parent.
- SpaceMax
- A widget that takes, at most, an amount of space in a Row, Column, or Flex widget.
- SpaceMin
- A flexible spacer with a minimum gap — optionally capped by max.
- SwapEffect
- An effect that swaps out the incoming child for a new child at a particular point in time. This includes all preceding effects. It uses a builder so that the effect can be reused, but note that the builder is only called once when the effect initially builds.
- SystemUiUtils
- Utility class to manage system UI (status bar, nav bar) appearance globally.
- TapSafeGesture
- TextAvatar
- A text avatar with auto initials and tinted colors.
- TextAvatarColors
- Resolved background + text colors from a single seed color.
- TextIcon
- A custom widget that displays a text with optional prefix and suffix widgets.
- TextShimmer
- TextShimmerState
- ThenEffect
- A special convenience "effect" that makes it easier to sequence effects after one another. It does this by establishing a new baseline time equal to the previous effect's end time and its own optional delay. All subsequent effect delays are relative to this new baseline.
- TicketClipper
- TicketRoundedEdgeClipper
- TicketRoundedEdgeClipper that can be used with ClipPath to clip widget in Ticket Rounded Edge shape
- TicketShadowPainter
- TimerBuilder
- A widget that rebuilds on specific and / or periodic Timer events.
- TintEffect
-
An effect that applies an animated color tint to the target (via ColorFiltered).
The begin and end values indicate the strength of the tint (0 - 0% tint, 1 - 100% tint).
Defaults to
begin=0, end=1. - ToggleEffect
- An effect that allows you to toggle the behavior of a builder function at a certain point in time.
- UnFocusable
- UniversalDigitCounter
- Validator
- ValueAdapter
-
Drives an Animate animation directly from a value in the range
0-1 - ValueColor
- 用来描述符合条件的 value 字体颜色
- ValueNotifierAdapter
-
Drives an Animate animation from a ValueNotifier. The value from the
notifier should be in the range
0-1. - VideoShimmer
- VideoShimmerState
- VisibilityEffect
-
An effect that toggles the visibility of the target (via Visibility).
Defaults to
end=true. - WidgetHelper
- WidgetsBindingx
-
为了适配flutter 2 中的
WidgetsBinding.instance可能为null - YoutubeShimmer
- YoutubeShimmerState
Enums
- AlignmentHorizontal
-
Horizontal placement on the
-1, 1alignment axis. - AlignmentVertical
-
Vertical placement on the
-1, 1alignment axis. - ArcType
- Arc drawing modes for CircularPercentIndicator.
- AvatarShape
- Avatar container shape.
- BorderAlign
- CircularStrokeCap
- Stroke caps for the circular progress stroke.
- CurrencyStyle
- Number grouping style for NumCurrencyExtension.toCurrency.
- CurrencySymbolPosition
-
Where the currency
symbolis placed relative to the amount. - CustomBannerLocation
- Where to show a Banner.
- DeviceType
- DigitAnimationType
- Direction
- DirectionMarguee
- A widget that displays its child in a scrolling manner.
- Edge
- FlutterScrollDirection
- A widget that displays a scrollable list of items with dynamic heights.
- FlutterTagAnimationType
-
This is a set of animations that you can use for your
badges.Tagwidget. Do not use them explicitly, use for exampleTagAnimation.slide()instead. - FlutterTagGradientType
- FlutterTagShape
- Enum representing the different shapes that can be used for a badge.
- FlutterToastPosition
- ImageBg
- ImageColor
- ImageSet
- ImageType
- InitialsMode
- How initials are derived from TextAvatar.text.
- LinearStrokeCap
- ListAnimationType
- PasswordRule
- PasswordStrength
- PickerStyle
- Visual style for the pickers.
- PrintfLevel
- Log severity used by printf and shortcuts like printfError.
- ShaderLayer
- TapEffect
- TrimMode
- TrimMode enum
Mixins
-
AnimateManager<
T> - Provides a common interface for Animate and AnimateList to attach Effect extensions.
- SU
Extensions
- AlignEffectExtensions on T
- Adds AlignEffect related extensions to AnimateManager.
- AlignmentDirectionalExtensions on AlignmentDirectional
-
Direction-aware checks for AlignmentDirectional using the
startaxis. - AlignmentExtensions on Alignment
- Flutter Alignment Reference (x, y)
- AlignmentGeometryExtensions on AlignmentGeometry
- AlignmentGeometry helpers that resolve against TextDirection.
-
AnimateListExtensions
on List<
Widget> -
Adds AnimateList related extensions to
List<Widget>. - AnimateOnWidget on Widget
- PAYDROP ULTIMATE ANIMATION ENGINE (UPDATED WITH REPEAT LOGIC) Rules:
- AnimateWidgetExtensions on Widget
- Adds Animate related extensions to Widget.
- AnimationControllerLoopExtensions on AnimationController
-
Adds a loop extension on AnimationController identical to repeat but
adding a
countparameter specifying how many times to repeat before stopping: - AnimationListViewItemWidget on Widget
- AnimationsBottomSheet on Widget
- BlurEffectExtensions on T
- Adds BlurEffect related extensions to AnimateManager.
- BooleanExtensions on bool
- Extensions for non-nullable bool values.
- BooleanOrNullExtensions on bool?
- Extensions for nullable bool values.
-
BoolValueListenableExtension
on ValueListenable<
bool> - BorderExtension on num?
- Border radius utilities.
- BorderRadiusExtension on BorderRadius
- BoxConstraintsExtension on BoxConstraints
- BoxShadowEffectExtensions on T
- Adds BoxShadowEffect related extensions to AnimateManager.
- BuildContextExension on BuildContext
- CallbackEffectExtensions on T
- Adds CallbackEffect related extensions to AnimateManager.
- CircularStrokeCapExtension on CircularStrokeCap
- ColorEffectExtension on T
- Adds ColorEffect related extensions to AnimateManager.
- ColumnExtension on Column
- ConversionExtension on Object?
- CrossfadeEffectExtensions on T
- Adds CrossfadeEffect related extensions to AnimateManager.
- CustomEffectExtensions on T
- Adds CustomEffect related extensions to AnimateManager.
- DateTimeExtension on DateTime
- DateTimeFormatExtension on DateTime
- DateTimeNullExtension on DateTime?
-
Extension for nullable
DateTimeto provide null check functionality. - DoubleNullSmartRoundExtension on double?
- DoubleOrNullExtensions on double?
-
Extension on
double?to provide utility methods for validation and null checking. - DoubleSmartRoundExtension on double
- DurationExtension on Duration
- Duration Extensions
- EdgeInsetsExtension on EdgeInsets
- EffectExtensions on T
- Adds Effect related extensions to AnimateManager.
- ElevationEffectExtensions on T
- Adds ElevationEffect related extensions to AnimateManager.
- EmailValidation on String
- FadeEffectExtensions on T
- Adds FadeEffect related extensions to AnimateManager.
- FlipEffectExtensions on T
- Adds FlipEffect related extensions to AnimateManager.
- FollowPathEffectExtensions on T
- Adds FollowPathEffect related extensions to AnimateManager.
-
GlobalWidgetListAnimations
on List<
Widget> - Hex on Color
- Color Extensions
- IntExtensions on int
- IntNullableExtensions on int?
- int Extensions
-
IterableExtension
on Iterable<
T> -
LastWhereExt
on List<
T> - ListenableExtension on Listenable
- ListenEffectExtensions on T
- Adds ListenEffect related extensions to AnimateManager.
-
ListExtension
on List<
T> ? -
ListExtNotNoll
on List<
T?> ? -
ListNullExtension
on List<
T> ? -
ListnumManipulation
on List<
num> ? -
ListWidgetExtension
on List<
Widget> -
MapExtension
on Map<
K, V> ? - Map
-
MapGetOrDefault
on Map<
K, V> - Typed getters for Map values — simple defaults and API/JSON parsing.
-
MapStringKeyExtension
on Map<
String, V> ? - MaterialColorExtension on MaterialColor
- MoveEffectExtensions on T
- Adds MoveEffect related extensions to AnimateManager.
-
NullableElementIterableExtension
on Iterable<
T?> - Extension methods for nullable Iterable<T?> to perform common operations such as finding the element that yields the highest value based on a selector.
-
NullableElementNullableIterableExtension
on Iterable<
T?> ? - List or Element may be null Extension methods for nullable Iterable<T?>? to provide operations on nullable iterables, such as filtering, mapping, reducing, and working with non-null values.
-
NullableIterableExtension
on Iterable<
T> ? - List may be null Extension methods for nullable Iterable to perform common operations safely, checking for null or empty conditions first.
- NullStringExtension on String?
- NumCurrencyExtension on num
- Formats numbers as currency strings (no localization dependency).
- NumDurationExtensions on num
- Adds extensions to num (ie. int & double) to make creating durations simple:
- NumExt on num?
- Num Extensions
- NumNullCurrencyExtension on num?
- Nullable currency formatting.
- NumNullSmartRoundExtension on num?
- NumSmartRoundExtension on num
- OffsetCopyWithExtensions on Offset
-
Adds a
copyWithmethod to Offset. - PaddingExtension on num
- Padding utilities.
- PaddingWidgetExtension on Widget
- PasswordStrengthColor on PasswordStrength
- PasswordStrengthExtension on String
- PasswordStrengthLable on PasswordStrength
- PasswordValidation on String
- PathSharpCornersExtensions on Path
- PhoneExtraction on String
- PhoneNumberValidation on String
- RadiusExtension on Radius
- RandomExtension on Random
- RotateEffectExtensions on T
- Adds RotateEffect related extensions to AnimateManager.
- RowExtension on Row
- SaturateEffectExtensions on T
- Adds SaturateEffect related extensions to AnimateManager.
- ScaleEffectExtensions on T
- Adds ScaleEffect related extensions to AnimateManager.
- ScopeFunction on T
- ScreenUtilPortrait on ScreenUtil
-
SetExtension
on Set<
E> - ShaderEffectExtensions on T
- Adds ShaderEffect related extensions to AnimateManager.
- ShakeEffectExtensions on T
- Adds ShakeEffect related extensions to AnimateManager.
- SharpBorderExtension on num?
- ShimmerEffectExtensions on T
- Adds ShimmerEffect related extensions to AnimateManager.
- SizeExtension on num
- SlideEffectExtensions on T
- Adds SlideEffect related extensions to AnimateManager.
- StringCaseExtensions on String
- Extension to convert strings into different cases. Supports snake_case, camelCase, PascalCase, kebab-case, SCREAMING_SNAKE_CASE, Title Case, and Sentence case.
- StringMaskExtension on String?
- String masking extensions for phone numbers, emails, and generic values.
- SwapEffectExtensions on T
- Adds SwapEffect related extensions to AnimateManager.
- TapEffectExt on TapEffect
- ThenEffectExtensions on T
- Adds ThenEffect related extensions to AnimateManager.
- TintEffectExtensions on T
- Adds TintEffect related extensions to AnimateManager.
- ToggleEffectExtensions on T
- Adds ToggleEffect related extensions to AnimateManager.
- UsernameValidation on String
-
ValueListenableExtension
on ValueListenable<
T> - VisibilityEffectExtensions on T
- Adds VisibilityEffect related extensions to AnimateManager.
- WidgetExtension on Widget?
- WidgetPaddingX on Widget
Constants
- inMaxValue → const int
- The biggest possible value of an int within 64 bits.
- intMinValue → const int
- The smallest possible value of an int within 64 bits.
- kAlignmentEpsilon → const double
- Default tolerance for comparing alignment coordinates to zero.
-
textAvatarColorData
→ const Map<
String, Color> - Default letter → seed color palette.
- whiteColor → const Color
Properties
- defaultBlurRadius ↔ double
-
getter/setter pair
- defaultRadius ↔ double
-
returns default InputDecoration for AppTextField widget
getter/setter pair
- defaultSpreadRadius ↔ double
-
getter/setter pair
-
flutterWidgets
→ HashSet<
String> -
final
- shadowColorGlobal ↔ Color
-
getter/setter pair
Functions
-
alignDateTime(
DateTime dt, Duration alignment, [bool roundUp = false]) → DateTime -
Rounds down or up a DateTime object using a Duration object.
If
roundUpis true, the result is rounded up, otherwise it's rounded down. If the duration is a multiple of days, the result will be aligned at the day mark in the timezone of the source datetime. -
alignmentIsNearZero(
double value, {double epsilon = kAlignmentEpsilon}) → bool -
Returns
truewhenvalueis effectively zero for alignment math. -
boxDecorationDefault(
{BorderRadiusGeometry? borderRadius, Color? color, Gradient? gradient, BoxBorder? border, BoxShape? shape, BlendMode? backgroundBlendMode, List< BoxShadow> ? boxShadow, DecorationImage? image}) → Decoration -
boxDecorationRoundedWithShadow(
int radiusAll, {Color backgroundColor = whiteColor, Color? shadowColor, double? blurRadius, double? spreadRadius, Offset offset = const Offset(0.0, 0.0), LinearGradient? gradient}) → Decoration - rounded box decoration with shadow
-
boxDecorationWithRoundedCorners(
{Color backgroundColor = whiteColor, BorderRadius? borderRadius, LinearGradient? gradient, BoxBorder? border, List< BoxShadow> ? boxShadow, DecorationImage? decorationImage, BoxShape boxShape = BoxShape.rectangle}) → Decoration - rounded box decoration
-
boxDecorationWithShadow(
{Color backgroundColor = whiteColor, Color? shadowColor, double? blurRadius, double? spreadRadius, Offset offset = const Offset(0.0, 0.0), LinearGradient? gradient, BoxBorder? border, List< BoxShadow> ? boxShadow, DecorationImage? decorationImage, BoxShape boxShape = BoxShape.rectangle, BorderRadius? borderRadius}) → Decoration - box decoration with shadow
-
createTimerStream(
TimerGenerator generator, Future stopSignal) → Stream< DateTime> -
Creates a stream tha produces DateTime objects at the times specified by the
generator. Stops the stream whenstopSignalis received. -
defaultBoxShadow(
{Color? shadowColor, double? blurRadius, double? spreadRadius, Offset offset = const Offset(0.0, 0.0)}) → List< BoxShadow> - default box shadow
-
defaultInputDecoration(
{String? hint, String? label, TextStyle? textStyle}) → InputDecoration -
degreeToRadian(
double degree) → double -
Converts degrees to radians.
Returns the equivalent value in radians for the given
degree. -
dialogShape(
[double? borderRadius]) → ShapeBorder -
fromIterable(
Iterable< DateTime> iterable) → TimerGenerator -
getAlignmentUnit(
Duration interval) → Duration - Returns an alignment unit can be passed to alignDateTime in order to align the date/time units. For example, if the specified interval is 15 minutes, the alignment unit is 1 minute.
-
getBytesFromAsset(
String path, {int? width}) → Future< Uint8List> - Checks the network connection by attempting to lookup 'google.com'.
-
hasMatch(
String? s, String p) → bool - Checks if a string matches a specified pattern.
-
hideStatusBar(
) → Future< void> - Hides both the status bar and navigation bar, making the app fullscreen.
-
horizontalAxisOf(
double x, {double epsilon = kAlignmentEpsilon}) → AlignmentHorizontal -
Resolves
xto a horizontal axis bucket. -
horizontalAxisOfDirectional(
double start, {double epsilon = kAlignmentEpsilon}) → AlignmentHorizontal -
Resolves directional
startto a horizontal axis bucket. -
periodicTimer(
Duration interval, {Duration alignment = Duration.zero}) → TimerGenerator -
primaryTextStyle(
{int? size, Color? color, FontWeight? weight, String? fontFamily, double? letterSpacing, FontStyle? fontStyle, double? wordSpacing, TextDecoration? decoration, TextDecorationStyle? textDecorationStyle, TextBaseline? textBaseline, Color? decorationColor, Color? backgroundColor, double? height}) → TextStyle -
printf(
Object? data, {Object? mapKey, int? listIndex, String? tag, PrintfLevel level = PrintfLevel.debug, Color? foreground, Color? background, bool italic = false, bool bold = false, bool underline = false, bool invert = false, bool strike = false, bool doubleUnderline = false, bool framed = false, bool? timestamp, bool? showFile, PrintfStyle? style, String? name, int stackTraceIndex = 1}) → void -
Prints
datato the console with optional ANSI styling, tags, and metadata. -
printfBox(
String title, Object? message, {PrintfLevel level = PrintfLevel.info, String? tag}) → void -
Prints a titled box around
message. -
printfCallerLinkFromStackTrace(
String stackTraceText) → String? - Resolves a clickable caller link from a StackTrace string (for tests).
-
printfDebug(
Object? data, {String? tag, PrintfStyle? style}) → void -
printfError(
Object? data, {String? tag, Object? error, StackTrace? stackTrace, PrintfStyle? style}) → void -
printfInfo(
Object? data, {String? tag, PrintfStyle? style}) → void -
printfSeparator(
{Object object = '', int length = 20}) → String - Horizontal rule with optional label — useful to group logs.
-
printfSuccess(
Object? data, {String? tag, PrintfStyle? style}) → void -
printfTable(
Map< String, Object?> rows, {String? title, PrintfLevel level = PrintfLevel.debug, String? tag}) → void - Prints key/value rows in a aligned block.
-
printfWarn(
Object? data, {String? tag, PrintfStyle? style}) → void -
printHttpRequest(
{required String method, required String url, Map< String, Object?> ? headers, Object? body, Iterable<String> ? files, String? tag = 'HTTP'}) → void -
Logs an outgoing HTTP request without coupling to
httpordio. -
printHttpResponse(
{required String method, required String url, required int statusCode, bool? success, Object? body, Duration? duration, String? tag = 'HTTP'}) → void - Logs an HTTP response summary.
-
radius(
[double? radius]) → BorderRadius - returns Radius
-
radiusCircular(
[double? radius]) → Radius - returns Radius
-
radiusOnly(
{double? topRight, double? topLeft, double? bottomRight, double? bottomLeft}) → BorderRadius - returns custom Radius on each side
-
randomString(
{int? length, bool includeNumeric = true}) → String - Generates a random alphanumeric string with a random length between 1 and 64.
-
resolveTextAvatarInitials(
String text, {InitialsMode mode = InitialsMode.words, int maxInitials = 2, String initialsBuilder(String name)?}) → String -
resolveTextAvatarSeedColor(
String text, String initials, {Color? baseColor, Map< String, Color> ? includeColor, Map<String, Color> palette = textAvatarColorData}) → Color -
scheduledTimer(
Iterable< DateTime> schedule) → TimerGenerator -
setDarkStatusBar(
) → void - Configures the system UI for a dark-themed status bar and navigation bar.
-
setLightStatusBar(
) → void - Configures the system UI for a light-themed status bar and navigation bar.
-
setOrientationLandscape(
) → void - Locks the screen orientation to landscape mode.
-
setOrientationPortrait(
) → void - Locks the screen orientation to portrait mode.
-
setStatusBarColor(
Color statusBarColor, {Brightness? statusBarBrightness, Brightness? statusBarIconBrightness, int delayInMilliSeconds = 200}) → Future< void> - Sets the status bar color and optional system navigation bar color.
-
showDialogWithCloseIcon<
T> ({required BuildContext context, required Widget title, required Widget content, Widget? closeIcon, VoidCallback? onTapCloseIcon, EdgeInsets? insetPadding, bool barrierDismissible = true, FlutterTagPosition? closeButtonPosition, FlutterTagAnimation? closeButtonAnimation, FlutterTagStyle? closeButtonStyle, Color? backgroundColor, Color? dialogColor, SharpRectangleBorder? shape}) → Future< T?> -
showStatusBar(
) → Future< void> - Restores the status bar and navigation bar visibility.
-
textAvatarHashColor(
String input) → Color - Stable fallback when no palette match exists.
-
timeAgoCalculated(
DateTime date, {DateTime? clock, bool allowFromNow = false, bool inHindi = false}) → String -
Formats provided
dateto a fuzzy time like 'a moment ago' -
verticalAxisOf(
double y, {double epsilon = kAlignmentEpsilon}) → AlignmentVertical -
Resolves
yto a vertical axis bucket. -
wait<
T> ([int millisecond = 1500, FutureOr< T> value()?]) → Future<T?> - Short for Future.delayed.
Typedefs
- AnimateCallback = void Function(AnimationController controller)
- Function signature for Animate callbacks.
- AnimatedSingleWidgetBuilder = Widget Function(Size size, String value, bool isNumber, Widget child)
- 自定义每一个 Widget
- BoolArgVoidCallback = void Function(bool arg)
- Define a function that takes a bool argument and returns void
- CustomEffectBuilder = Widget Function(BuildContext context, double value, Widget child)
- DoubleArgVoidCallback = void Function(double arg)
- Define a function that takes a double argument and returns void
- DoubleCallback = double Function()
- Define a function that returns a double and takes no arguments
- DynamicArgVoidCallback = void Function(dynamic arg)
- Define a function that takes a dynamic argument and returns void
- DynamicCallback = dynamic Function()
- Define a function that returns a dynamic and takes no arguments
- FontSizeResolver = double Function(num fontSize)
- FormatValue = String Function(String value)
- 格式化最终显示的值
-
FutureDoubleCallback
= Future<
double> Function() - Define a function that returns a double and takes no arguments
- FutureDynamicCallback = Future Function()
- Define a function that returns a dynamic and takes no arguments
-
FutureIntCallback
= Future<
int> Function() - Define a function that returns a int and takes no arguments
-
FutureStringCallback
= Future<
String> Function() - Define a function that returns a String and takes no arguments
-
FutureVoidCallback
= Future<
void> Function() - Define a function that returns a void and takes no arguments
- IntArgVoidCallback = void Function(int arg)
- Define a function that takes an int argument and returns void
- IntCallback = int Function()
- Define a function that returns an int and takes no arguments
- MaxSpace = SpaceMax
- Deprecated alias for SpaceMax.
- RatingChangeCallback = void Function(double rating)
- RebuildFactor = bool Function(MediaQueryData old, MediaQueryData data)
- ReparentChildBuilder = Widget Function(Widget parent, Widget child)
- The builder type used by Animate.reparentTypes. It must accept an existing parent widget, and rebuild it with the provided child. In effect, it clones the provided parent widget with the new child.
- ScreenUtilInitBuilder = Widget Function(BuildContext context, Widget? child)
- ShaderUpdateCallback = EdgeInsets? Function(ShaderUpdateDetails details)
- Function signature for ShaderEffect update handlers.
- StringArgVoidCallback = void Function(String arg)
- Define a function that takes a String argument and returns void
- StringCallback = String Function()
- Define a function that returns a String and takes no arguments
- TimerGenerator = DateTime? Function(DateTime now)
- Used by TimerBuilder to determine the next DateTime to trigger a rebuild on
- ToggleEffectBuilder = Widget Function(BuildContext context, bool value, Widget child)
- ValueChangeTextStyle = TextStyle Function(TextStyle style)
- 当值符合条件时,改变颜色
- ValueColorCondition = bool Function()
- 当值符合条件时,改变颜色