flutter_helper_kit_widgets library
Widgets-only entry point for flutter_helper_kit.
import 'package:flutter_helper_kit/flutter_helper_kit_widgets.dart';
Classes
-
ActionSheetItem<
T> - Generic model for action sheet items.
- AnimatedDigitController
- 动画数字控制器
- AnimatedDigitWidget
- 动画数字 Widget
- AnimatedDigitWidgetState
- Annotation
- Defines a customizable pattern within text, such as hashtags, URLs, or mentions.
- AppButton
- Default App Button
- AppButtonState
- AppCupertinoActionSheet
- AppCupertinoDialog
- AvatarGlow
- A widget that adds a glowing effect around its child.
- AvatarGlowMultiColor
- A widget that adds a glowing effect around with multipale colors its child.
- CenterTextDivider
- CircleClipper
- CustomBanner
- CustomIndicator
- DashDivider
- DottedBorderWidget
- DottedBorderWidgetState
- DoublePressBackWidget
- A widget that handles double press back navigation.
-
DropdownItem<
T> -
FlutterListView<
T> - A widget that displays a list of items with dynamic heights in a scrollable view.
- FlutterTag
- FlutterTagAnimation
- FlutterTagBorderGradient
- A custom BoxBorder that draws a gradient border around a widget.
- FlutterTagGradient
- A utility class for creating gradients of various types used in Flutter badges.
- FlutterTagPosition
- FlutterTagPositioned
-
A widget that positions a child widget within a parent widget using
the provided
FlutterTagPositionBaseparameters. - FlutterTagState
- FlutterTagStyle
- FlutterToast
- the package library class for calling from client end.
-
GenericPickerSheet<
T extends DropdownItem> - Material bottom-sheet picker for single or multi-select dropdown lists.
- GoogleLogoWidget
- A widget that displays the Google logo using CustomPaint.
- GradientText
- ListTileShimmer
- ListTileShimmerState
- ListViewPagination
- Marquee
- MaxSpace
- A widget that takes, at most, an amount of space in a Row, Column, or Flex widget.
- MyDropdownItem
- NP
- OutlineAvatarGlow
- OutlineAvatarGlowMultiColor
- PasswordStrengthIndicator
- PasswordStrengthIndicatorState
- PlayStoreShimmer
- PlayStoreShimmerState
- PointedEdgeClipper
- PointedEdgeClipper that can be used with ClipPath to clip widget in Pointed Edge shape
- ProfilePageShimmer
- ProfilePageShimmerState
- ProfileShimmer
- ProfileShimmerState
- RatingBarWidget
- RatingBarWidget
- RatingBarWidgetState
- ReadMoreText
- ReadMoreTextEnhanced
- ReadMoreTextEnhancedState
- ReadMoreTextState
- RenderSliverSpace
- RoundedCheckBox
- Widget that draw a beautiful checkbox rounded. Provided with animation if wanted
- RoundedCheckBoxState
- RoundedEdgeClipper
- RoundedEdgeClipper that can be used with ClipPath to clip widget in Rounded Edge shape
- SeparatedColumn
- A widget that arranges its children in a vertical column with separators between them.
- ShadowRadius
- SharpBorderRadius
- SharpCircleBorder
- SharpClipCircle
- SharpClipRect
- SharpProcessedRadius
- SharpRadius
- SharpRectangleBorder
- SingleDigitData
- 单个包装的字符/数字依赖配置数据源
- SingleDigitProvider
-
The SingleDigitData
DIprovider widget - SliderButton
- SlideTween
- SliverSpace
- A sliver that takes a fixed amount of space.
- Space
- A widget that takes a fixed amount of space in the direction of its parent.
- TapSafeGesture
- TextAvatar
- A widget to display a text avatar with a background color.
- TextIcon
- A custom widget that displays a text with optional prefix and suffix widgets.
- TextShimmer
- TextShimmerState
- TicketClipper
- TicketRoundedEdgeClipper
- TicketRoundedEdgeClipper that can be used with ClipPath to clip widget in Ticket Rounded Edge shape
- TicketShadowPainter
- TimerBuilder
- A widget that rebuilds on specific and / or periodic Timer events.
- UnFocusable
- UniversalDigitCounter
- ValueColor
- 用来描述符合条件的 value 字体颜色
- VideoShimmer
- VideoShimmerState
- WidgetHelper
- WidgetsBindingx
-
为了适配flutter 2 中的
WidgetsBinding.instance可能为null - YoutubeShimmer
- YoutubeShimmerState
Enums
- BorderAlign
- CustomBannerLocation
- Where to show a Banner.
- DigitAnimationType
- DirectionMarguee
- A widget that displays its child in a scrolling manner.
- Edge
- FlutterScrollDirection
- A widget that displays a scrollable list of items with dynamic heights.
- FlutterTagAnimationType
-
This is a set of animations that you can use for your
badges.Tagwidget. Do not use them explicitly, use for exampleTagAnimation.slide()instead. - FlutterTagGradientType
- FlutterTagShape
- Enum representing the different shapes that can be used for a badge.
- FlutterToastPosition
- PasswordRule
- PasswordStrength
- TrimMode
- TrimMode enum
Extensions
Constants
- inMaxValue → const int
- The biggest possible value of an int within 64 bits.
- intMinValue → const int
- The smallest possible value of an int within 64 bits.
Functions
-
alignDateTime(
DateTime dt, Duration alignment, [bool roundUp = false]) → DateTime -
Rounds down or up a DateTime object using a Duration object.
If
roundUpis true, the result is rounded up, otherwise it's rounded down. If the duration is a multiple of days, the result will be aligned at the day mark in the timezone of the source datetime. -
createTimerStream(
TimerGenerator generator, Future stopSignal) → Stream< DateTime> -
Creates a stream tha produces DateTime objects at the times specified by the
generator. Stops the stream whenstopSignalis received. -
fromIterable(
Iterable< DateTime> iterable) → TimerGenerator -
getAlignmentUnit(
Duration interval) → Duration - Returns an alignment unit can be passed to alignDateTime in order to align the date/time units. For example, if the specified interval is 15 minutes, the alignment unit is 1 minute.
-
periodicTimer(
Duration interval, {Duration alignment = Duration.zero}) → TimerGenerator -
scheduledTimer(
Iterable< DateTime> schedule) → TimerGenerator
Typedefs
- AnimatedSingleWidgetBuilder = Widget Function(Size size, String value, bool isNumber, Widget child)
- 自定义每一个 Widget
- FormatValue = String Function(String value)
- 格式化最终显示的值
- RatingChangeCallback = void Function(double rating)
- TimerGenerator = DateTime? Function(DateTime now)
- Used by TimerBuilder to determine the next DateTime to trigger a rebuild on
- ValueChangeTextStyle = TextStyle Function(TextStyle style)
- 当值符合条件时,改变颜色
- ValueColorCondition = bool Function()
- 当值符合条件时,改变颜色