RxnDateTime class
Nullable reactive DateTime.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
DateTime?> - RxnDateTime
- Available extensions
Constructors
- RxnDateTime(DateTime? initial)
- RxnDateTime.nowOrNull()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isNullOrToday → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ DateTime?
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addDuration(
Duration duration) → RxnDateTime -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
builder(
{required TransitionBuilder builder, Widget? child}) → Widget -
Available on Listenable, provided by the ListenableExtension extension
Provides anAnimatedBuilderwidget that listens to theListenableand rebuilds its widget tree when the animation value changes. -
differenceInDays(
DateTime other) → int? -
differenceInHours(
DateTime other) → int? -
differenceInMinutes(
DateTime other) → int? -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
format(
[String pattern = 'yyyy-MM-dd HH:mm:ss']) → String? -
isAfter(
DateTime other) → bool? -
isAtSameMomentAs(
DateTime other) → bool? -
isBefore(
DateTime other) → bool? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setTime(
{int hour = 0, int minute = 0, int second = 0, int millisecond = 0}) → RxnDateTime -
subtractDuration(
Duration duration) → RxnDateTime -
timeAgo(
) → String? -
toLocalTime(
) → RxnDateTime -
toString(
) → String -
A string representation of this object.
inherited
-
toUtcTime(
) → RxnDateTime
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited