PrintfStyle class

ANSI styling for printf output.

Some terminals/IDEs may not render every style. See ANSI escape codes.

Constructors

PrintfStyle({Color? foreground, Color? background, bool italic = false, bool bold = false, bool underline = false, bool invert = false, bool strike = false, bool doubleUnderline = false, bool framed = false})
const

Properties

background Color?
final
bold bool
final
doubleUnderline bool
final
foreground Color?
final
framed bool
final
hashCode int
The hash code for this object.
no setterinherited
invert bool
final
italic bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strike bool
final
underline bool
final

Methods

applyTo(String text) String
Wraps text with ANSI escape sequences for the active style flags.
copyWith({Color? foreground, Color? background, bool? italic, bool? bold, bool? underline, bool? invert, bool? strike, bool? doubleUnderline, bool? framed}) PrintfStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

debug → const PrintfStyle
Grey italic text — debug noise.
error → const PrintfStyle
Red bold text — errors.
info → const PrintfStyle
Blue text — informational logs.
network → const PrintfStyle
Cyan underline — network / API logs.
success → const PrintfStyle
Green bold text — success messages.
warning → const PrintfStyle
Orange bold text — warnings.