MapCustomInfoWindowController class
Controller to add, update and control the custom info window.
Constructors
Properties
- addInfoWindow ↔ dynamic Function(Widget, MapLatLng, double, double, double)?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideInfoWindow ↔ VoidCallback?
-
getter/setter pair
- mapAdapter ↔ MapInfoWindowAdapter?
-
getter/setter pair
- onCameraMove ↔ VoidCallback?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showInfoWindow ↔ VoidCallback?
-
getter/setter pair
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited