RandomPicsumImage class

Constructors

RandomPicsumImage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

byId({required int id, int width = 400, int height = 300}) String
Get an image by ID
bySeed({required String seed, int width = 400, int height = 300, bool grayscale = false, int blur = 0}) String
Get a seeded image (consistent image for a given string seed)
image({int width = 400, int height = 300, bool grayscale = false, int blur = 0}) String
Get a random image with specified width and height
info(int id) String
Get metadata for a specific image
list({int page = 1, int limit = 30}) String
Get random image info (JSON API - for custom usage)