widgets/flutter_percent_indicator/flutter_percent_indicator library
Percent / progress indicators for flutter_helper_kit.
import 'package:flutter_helper_kit/widgets/flutter_percent_indicator/flutter_percent_indicator.dart';
// or via the main package / widgets barrel
Classes
- CircularPercentIndicator
- A circular progress indicator with optional animation, gradients, and arcs.
- LinearPercentIndicator
- A linear progress indicator with optional animation, gradients, and labels.
- MultiSegmentLinearIndicator
- A multi-segment linear progress bar.
- SegmentLinearIndicator
- A colored segment for MultiSegmentLinearIndicator.
Enums
- ArcType
- Arc drawing modes for CircularPercentIndicator.
- CircularStrokeCap
- Stroke caps for the circular progress stroke.
- LinearStrokeCap